@@ -17,131 +17,11 @@ for (i in 1:10){
   format.tucson[[i]] = parse(text=paste(format.str, ")", sep=""))
 }
 
-# Internal function.
-# Increment the given number (vector) x by one in the given base.
-# Well, kind of: we count up to and including base (not base-1), and
-# the smallest digit is one. Basically, we have a shift of one because
-# of array indices starting from 1 instead of 0.  In case another
-# digit is needed in the front, vector x grows.
-count.base <- function(x, base){
-  n.x = length(x)
-  pos = n.x
-  x[pos] = x[pos] + 1
-  while (x[pos] == base + 1){
-    x[pos] = 1
-    if (pos == 1){
-      temp = vector(mode="integer", length=n.x+1)
-      temp[2:(n.x+1)] = x
-      pos = 2
-      x = temp
-    }
-    x[pos-1] = x[pos-1] + 1
-    pos = pos - 1
-  }
-  x
-}
-
-# Internal function.
-# Compose a new name by attaching a suffix, which may partially
-# replace the original name depending on the limit imposed on the
-# length of names.
-compose.name <- function(orig.name, alphabet, idx, limit){
-  idx.length = length(idx)
-  if (idx.length > limit){
-    new.name = ""
-  } else{
-    last.part = paste(alphabet[idx], collapse="")
-    first.part = substr(orig.name, 1, limit-idx.length)
-    new.name = paste(first.part, last.part, sep="")
-  }
-  new.name
-}
-
-# Internal function.
-# Fix names so that they are unique and no longer than the given
-# length.  A reasonable effort will be done in the search for a set of
-# unique names, although some stones will be left unturned. The
-# approach should be good enough for all but the most pathological
-# cases.
-fix.names <- function(x, limit,mapping.fname,mapping.append){
-  x.cut = substr(x, 1, limit)
-  unique.cut = unique(x.cut)
-  n.unique = length(unique.cut)
-  n.x = length(x)
-  # Check if there are duplicate names after truncation.
-  # No duplicates => nothing to do beyond this point, except return the result.
-  if (n.unique == n.x){
-    y = x.cut
-  } else {
-    warning("Duplicate names present. Renaming series.")
-    if(nchar(mapping.fname)>0){
-      write.map = TRUE
-      if(mapping.append) {
-        if(!file.exists(mapping.fname)){
-          stop("mapping.fname does not exist, can\'t append")
-        } else{
-          map.file = file(mapping.fname, "a")
-        }
-      } else{
-        map.file = file(mapping.fname, "w")
-      }
-    } else{
-      write.map = FALSE
-    }
-
-    y = character(length=n.x)
-    alphanumeric = c(0:9, LETTERS, letters)
-    n.an = length(alphanumeric)
-    # First pass: Keep already unique names
-    for (i in 1:n.unique){
-      idx.this = which(x.cut %in% unique.cut[i])
-      n.this = length(idx.this)
-      if (n.this == 1)
-        y[idx.this] = x.cut[idx.this]
-    }
-
-    x.cut2 = substr(x.cut, 1, limit-1)
-    x.cut2[y != ""] = NA
-    unique.cut2 = unique(x.cut2) # may contain NA
-    n.unique2 = length(unique.cut2)
-    # Second pass (exclude names that were set in the first pass):
-    # Make rest of the names unique
-    for (i in 1:n.unique2){
-      this.substr = unique.cut2[i]
-      if (is.na(this.substr)) # skip NA
-        next
-      idx.this = which(x.cut2 %in% this.substr)
-      n.this = length(idx.this)
-      suffix.count = 0
-      for (j in 1:n.this){
-        still.looking = TRUE
-        while (still.looking){
-          suffix.count = count.base(suffix.count, n.an)
-          proposed =
-            compose.name(unique.cut2[i],alphanumeric,suffix.count,limit)
-          if (nchar(proposed)==0){
-            warning("Could not remap a name. Some series will be missing.")
-            still.looking = FALSE
-            proposed = paste(unique.cut2[i], "F", sep="") # F for Fail...
-          } else if (!any(y %in% proposed)){
-            still.looking = FALSE
-          }
-        }
-        y[idx.this[j]] = proposed
-        if (write.map)
-          cat(x[idx.this[j]], "\t", proposed, "\n", file=map.file, sep = "")
-      }
-    }
-    if(write.map)
-      close(map.file)
-  }
-  y
-}
-
 # Exportable function
 `write.tucson` <-
 function(rwl.df, fname, header=NULL, append=FALSE, prec=0.01, mapping.fname="", mapping.append=FALSE, long.names=FALSE)
 {
+  line.term <- "\x0D\x0A" # CR+LF, ASCII carriage return and line feed
   if(!(prec == 0.01 | prec == 0.001)) stop('prec must eq 0.01 or 0.001')
   if(append) {
     if(!file.exists(fname)) stop("fname does not exist, can\'t append")
@@ -203,20 +83,17 @@ function(rwl.df, fname, header=NULL, append=FALSE, prec=0.01, mapping.fname="",
     hdr2 = paste(site.id, "   ", state.country,spp," ",elev,"  ",
       lat.long, "          ", yrs, sep="")
     hdr3 = paste(site.id, "   ", lead.invs, comp.date, sep="")
-    hdr = c(hdr1,hdr2,hdr3)
   }
 
   # Loop through series and write each one
   nseries <- ncol(rwl.df)
   yrs.all = as.numeric(rownames(rwl.df))
   col.names = colnames(rwl.df)
-  if(length(grep("^([a-z]|[0-9])+$", col.names, ignore.case = TRUE)) != nseries)
-    stop("Series names must only contain alphanumeric characters")
 
   # Sort years using increasing order, reorder rwl.df accordingly
   yrs.order = sort.list(yrs.all)
   yrs.all = yrs.all[yrs.order]
-  rwl.df = as.data.frame(rwl.df[yrs.order,])
+  rwl.df = rwl.df[yrs.order, , drop=FALSE]
 
   first.year = yrs.all[1]
   last.year = yrs.all[length(yrs.all)]
@@ -274,9 +151,9 @@ function(rwl.df, fname, header=NULL, append=FALSE, prec=0.01, mapping.fname="",
   else
     rwl.out = file(fname, "w")
   if(length(header)>0){
-    cat(hdr1, "\n", file=rwl.out, sep="")
-    cat(hdr2, "\n", file=rwl.out, sep="")
-    cat(hdr3, "\n", file=rwl.out, sep="")
+    cat(hdr1, line.term, file=rwl.out, sep="")
+    cat(hdr2, line.term, file=rwl.out, sep="")
+    cat(hdr3, line.term, file=rwl.out, sep="")
   }
   na.str = ifelse(prec == 0.01, 9.99, -9.999)
   missing.str = ifelse(prec == 0.01, -9.99, 0)
@@ -359,7 +236,7 @@ function(rwl.df, fname, header=NULL, append=FALSE, prec=0.01, mapping.fname="",
       dec.rwl=eval(format.tucson[[length(dec.rwl)]])
 
       dec.str = paste(rwl.df.name,opt.space,dec.year1,dec.rwl,sep="")
-      cat(dec.str, "\n", file = rwl.out, sep="")
+      cat(dec.str, line.term, file = rwl.out, sep="")
     }
   }
   close(rwl.out)
